@@ -1,10 +1,11 @@
-#' gen_alternative_terms
+#' Find similar search terms
 #'
 #' @description Function to find search terms that are similar or related to one another in spelling and also represented in the GENESIS, Zensus 2022 or regionalstatistik.de databases. Important note: The API call is searching for terms with the same characters. To be useful in searching for related terms it is highly recommended to work with "*" placeholders (see examples). The placeholder can be placed before and/or after the search term.
 #'
 #' @param term Character string. Maximum length of 15 characters. Term or word for which you are searching for alternative or related terms. Use of '*' as a placeholder is possible to generate broader search areas.
 #' @param similarity Boolean. Indicator if the output of the function should be sorted based on a Levenshtein edit distance based on the \code{adist()} function. Default is 'TRUE'.
 #' @param database Character string. Indicator if the GENESIS ('genesis'), Zensus 2022 ('zensus') or regionalstatistik.de ('regio') database is called. Default option is 'all'.
+#' @param pagelength Integer. Maximum length of results or objects (e.g., number of tables). Defaults to 500. Maximum of the databases is 25,000 objects.
 #' @param verbose Boolean. Indicator if the output of the function should include detailed messages and warnings. Default option is 'TRUE'. Set the parameter to 'FALSE' to suppress additional messages and warnings.
 #' @param ... Additional parameters for the API call. These parameters are only affecting the call itself, no further processing. For more details see `vignette("additional_parameter")`.
 #'
@@ -27,48 +28,58 @@
 gen_alternative_terms <- function(term = NULL,
                                   similarity = TRUE,
                                   database = c("all", "genesis", "zensus", "regio"),
+                                  pagelength = 500,
                                   verbose = TRUE,
                                   ...) {
+
+  # Determine calling function; important for checking parameter values
   caller <- as.character(match.call()[1])
 
-  gen_fun <- test_database_function(database,
-                                    error.input = TRUE,
-                                    text = verbose)
-
+  # Check parameter values
   check_function_input(term = term,
                        similarity = similarity,
+                       pagelength = pagelength,
                        caller = caller,
                        verbose = verbose)
 
+  # Check availability of credentials for the database(s) selected
+  database_vector <- test_database_function(database,
+                                            error.input = TRUE,
+                                            text = verbose)
+
   #-----------------------------------------------------------------------------
 
-  res <- lapply(gen_fun, function(db){
+  # Loop over databases in database_vector and make respective API calls
+  res <- lapply(database_vector, function(db){
 
-    if (verbose) {
+    if (isTRUE(verbose)) {
 
-      info <- paste("Started the processing of", rev_database_function(db), "database.")
+      info <- paste("Started the processing of", db, "database.")
 
       message(info)
 
     }
 
-    par_list <-  list(endpoint = "catalogue/terms",
-                      username = gen_auth_get(database = rev_database_function(db))$username,
-                      password = gen_auth_get(database = rev_database_function(db))$password,
-                      selection = term,
-                      ...)
-
-    results_raw <- do.call(db, par_list)
+    # Make API call
+    results_raw <- gen_api(endpoint = "catalogue/terms",
+                           database = db,
+                           username = gen_auth_get(database = db)$username,
+                           password = gen_auth_get(database = db)$password,
+                           selection = term,
+                           pagelength = pagelength,
+                           ...)
 
     #---------------------------------------------------------------------------
 
+    # Test validity of JSON results
     results_json <- test_if_json(results_raw)
 
-    if (length(results_json$List) == 0  & length(gen_fun) == 1) {
+    # Begin data processing based on function parameters
+    if (length(results_json$List) == 0 & length(database_vector) == 1) {
 
       stop("No related terms found for your code.", call. = FALSE)
 
-    } else if (length(results_json$List) == 0  & length(gen_fun) > 1) {
+    } else if (length(results_json$List) == 0 & length(database_vector) > 1) {
 
       termslist <- "No related terms found for your code."
 
@@ -76,7 +87,7 @@ gen_alternative_terms <- function(term = NULL,
 
     } else {
 
-      # similarity von Woertern berechnen und nach diesen Ordnen?
+      # Calculate similarity of words and order
 
       termslist <- c()
 
@@ -113,8 +124,9 @@ gen_alternative_terms <- function(term = NULL,
 
     }
 
+    # Append attributes to the result object(s)
     attr(list_resp, "Term") <- term
-    attr(list_resp, "Database") <- rev_database_function(db)
+    attr(list_resp, "Database") <- db
     attr(list_resp, "Language") <- results_json$Parameter$language
     attr(list_resp, "Pagelength") <- results_json$Parameter$pagelength
     attr(list_resp, "Copyright") <- results_json$Copyright
@@ -123,6 +135,7 @@ gen_alternative_terms <- function(term = NULL,
 
   })
 
+  # Check validity of results
   res <- check_results(res)
 
   return(res)
