@@ -30,6 +30,7 @@ with_mock_dir("find1", {
 #-------------------------------------------------------------------------------
 
 with_mock_dir("find2_fake", {
+
   test_that("gen_find errors if there is an error code (fake response)", {
 
     # Here, the mockfile needs to be altered:
@@ -39,9 +40,8 @@ with_mock_dir("find2_fake", {
     skip_on_cran()
     skip_on_ci()
 
-    expect_error(
-      gen_find(term = "bus", error.ignore = TRUE, database = "genesis"),
-      regexp = "test error message")
+    expect_error(object = gen_find(term = "bus", error.ignore = TRUE, database = "genesis"),
+                 regexp = "test error message")
 
   })
 
@@ -50,14 +50,14 @@ with_mock_dir("find2_fake", {
 #-------------------------------------------------------------------------------
 
 with_mock_dir("find3", {
+
   test_that("gen_find messages for 'detailed = TRUE'", {
 
     skip_on_cran()
     skip_on_ci()
 
-    expect_message(
-      gen_find(term = "zensus", error.ignore = TRUE, database = "genesis"),
-      regexp = "Use 'detailed = TRUE' to obtain the complete output.")
+    expect_message(object = gen_find(term = "zensus", error.ignore = TRUE, database = "genesis"),
+                   regexp = "Use 'detailed = TRUE' to obtain the complete output.")
 
   })
 
@@ -72,9 +72,8 @@ test_that("gen_find function errors on numeric term param", {
   skip_on_cran()
   skip_on_ci()
 
-  expect_error(
-    gen_find(term = 12345, detailed = TRUE, category = "tables", database = "genesis"),
-    regexp = "Parameter 'term' has to be of type 'character'.")
+  expect_error(object = gen_find(term = 12345, detailed = TRUE, category = "tables", database = "genesis"),
+               regexp = "Parameter 'term' has to be of type 'character'.")
 
 })
 
@@ -83,9 +82,8 @@ test_that("gen_find function errors on wrong category", {
   skip_on_cran()
   skip_on_ci()
 
-  expect_error(
-    gen_find(term = "bus", detailed = TRUE, category = "table", database = "genesis"),
-    regexp = "Available categories for parameter 'category' for 'genesis' database are 'all', 'tables', 'statistics', 'variables', and 'cubes'.")
+  expect_error(object = gen_find(term = "bus", detailed = TRUE, category = "table", database = "genesis"),
+               regexp = "Available categories for parameter 'category' for 'genesis' database are 'all', 'tables', 'statistics', 'variables', and 'cubes'.")
 
 })
 
@@ -94,9 +92,8 @@ test_that("gen_find function errors on wrong detailed param", {
   skip_on_cran()
   skip_on_ci()
 
-  expect_error(
-    gen_find(term = "bus", detailed = 1, category = "tables", database = "genesis"),
-    regexp = "Parameter 'detailed' has to be of type 'logical' and of length 1.")
+  expect_error(object = gen_find(term = "bus", detailed = 1, category = "tables", database = "genesis"),
+               regexp = "Parameter 'detailed' has to be of type 'logical' and of length 1.")
 
 })
 
@@ -105,9 +102,8 @@ test_that("gen_find function errors on wrong ordering param", {
   skip_on_cran()
   skip_on_ci()
 
-  expect_error(
-    gen_find(term = "bus", ordering = 1, category = "tables", database = "genesis"),
-    regexp = "Parameter 'ordering' has to be of type 'logical' and of length 1.")
+  expect_error(object = gen_find(term = "bus", ordering = 1, category = "tables", database = "genesis"),
+               regexp = "Parameter 'ordering' has to be of type 'logical' and of length 1.")
 
 })
 
@@ -116,8 +112,7 @@ test_that("gen_find function errors on wrong error.ignore param", {
   skip_on_cran()
   skip_on_ci()
 
-  expect_error(
-    gen_find(term = "bus", error.ignore = 1, category = "tables", database = "genesis"),
-    regexp = "Parameter 'error.ignore' has to be of type 'logical' and of length 1.")
+  expect_error(object = gen_find(term = "bus", error.ignore = 1, category = "tables", database = "genesis"),
+               regexp = "Parameter 'error.ignore' has to be of type 'logical' and of length 1.")
 
 })
